<?php

declare(strict_types=1);

namespace Drupal\simple_interactive_maps\Controller;

use Drupal\Core\Cache\CacheableResponse;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\simple_interactive_maps\InteractiveMapInterface;
use Drupal\simple_interactive_maps\MapDataLoader;
use Drupal\simple_interactive_maps\SvgHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\HttpException;

/**
 * Returns responses for Simple Interactive Maps routes.
 */
final class MapThumbnailController extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(
    private MapDataLoader $simpleInteractiveMapsMapDataLoader,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('simple_interactive_maps.map_data_loader'),
    );
  }

  /**
   * Builds the response.
   */
  public function __invoke(InteractiveMapInterface $interactive_map = NULL): CacheableResponse {

    $regions = $this->simpleInteractiveMapsMapDataLoader->loadMapData($interactive_map);

    $svgAttributes = [
      'xmlns' => 'http://www.w3.org/2000/svg',
      'xmlns:xlink' => 'http://www.w3.org/1999/xlink',
      'preserveAspectRatio' => 'xMidYMid meet',
      'version' => '1.1',
      'height' => '300',
    ];

    $bboxPaths = [];
    $svgPaths = '';

    foreach ($regions as $region) {
      $pathData = $region['svg-data']['paths'][0];
      $bboxPaths[] = $pathData;
      $svgPaths .= '<path d="' . $pathData . '" fill="' . $region['fill_color'] . '" stroke="' . $region['stroke_color'] . '" stroke-width="1" stroke-linejoin="round" />';
    }

    $viewBox = SvgHelper::calculateViewBox($bboxPaths);
    $svgAttributes['viewBox'] = $viewBox;

    $svgString = '<svg';
    foreach ($svgAttributes as $key => $value) {
      $svgString .= ' ' . $key . '="' . $value . '"';
    }
    $svgString .= '>' . $svgPaths . '</svg>';

    $response = new CacheableResponse($svgString, 200);
    $response->headers->set('Content-Type', 'image/svg+xml');

    $response->addCacheableDependency($interactive_map);

    return $response;
  }

}
